import setuptools

setuptools.setup(
    name="pysnver",
    version="0.2.2",
    description="python sn verify",
    packages=['pysnver'],
    package_data={'pysnver': ['so/*']},
    classifiers=[
        "Programming Language :: Python :: 3"
    ],
)

